#!/usr/bin/env python3
import dbus
import os
import sys

UPDATE_SUCCESS_FILE = "/update/update_success"
DESKTOP_OPEN_SUCCESS = "/update/desktop_success"
NEEDRECORVER = "/update/needrecorverrootfs"

def get_iface():
    bus = dbus.SystemBus()
    proxy = bus.get_object('com.kylin.OtaUpdate', '/com/kylin/OtaUpdate')
    return dbus.Interface(proxy, dbus_interface='com.kylin.OtaUpdate')

def call_desktop_open_success():
    if os.path.isfile(NEEDRECORVER):
        # 若需要还原系统
        try:
            iface = get_iface()
            iface.RecorverRootfs()
            print("RecorverRootfs() 调用成功")
        except dbus.DBusException as e:
            print("RecorverRootfs 调用失败:", str(e))
        return  # 仅执行恢复，退出函数

    # 若文件不存在，直接退出
    if not os.path.isfile(UPDATE_SUCCESS_FILE) or os.path.isfile(DESKTOP_OPEN_SUCCESS):
        sys.exit(0)

    try:
        iface = get_iface()
        iface.DesktopOpenSuccess()
        print("DesktopOpenSuccess() 调用成功")

        # 写入标志文件，避免重复调用
        with open(DESKTOP_OPEN_SUCCESS, "w") as f:
            f.write("done\n")

    except dbus.DBusException as e:
        print("DesktopOpenSuccess 调用失败:", str(e))

if __name__ == '__main__':
    call_desktop_open_success()
